
## ----echo=FALSE----------------------------------------------------------
results = "hide"; echo = FALSE


## ----setup, include=FALSE, cache=FALSE-----------------------------------
library(knitr)
options(replace.assign=FALSE,width=50)

opts_chunk$set(fig.path='knitr_figure/graphics-', 
               cache.path='knitr_cache/graphics-', 
               fig.align='center', 
               dev='pdf', fig.width=5, fig.height=5, 
               fig.show='hold', cache=FALSE, par=TRUE)
knit_hooks$set(crop=hook_pdfcrop)

knit_hooks$set(par=function(before, options, envir){
    if (before && options$fig.show!='none') {
        par(mar=c(3,3,2,1),cex.lab=.95,cex.axis=.9,
            mgp=c(2,.7,0),tcl=-.01, las=1)
}}, crop=hook_pdfcrop)


## ----eval=FALSE----------------------------------------------------------
## install.packages("ggplot2")


## ----eval=FALSE, tidy=FALSE----------------------------------------------
## ##Windows & Linux users
## install.packages("nclRggplot2",
##                  repos="http://R-Forge.R-project.org")
## ##Apple users
## install.packages("nclRggplot2",
##                  repos="http://R-Forge.R-project.org",
##                  type="source")


## ----message=FALSE-------------------------------------------------------
library(nclRggplot2)


## ----eval=FALSE----------------------------------------------------------
## install.packages("ggplot2")


## ------------------------------------------------------------------------
library(ggplot2)


## ------------------------------------------------------------------------
library(nclRggplot2)
data(Beauty)


## ----results='hide'------------------------------------------------------
head(Beauty)
colnames(Beauty)
dim(Beauty)


## ----fig.keep='none'-----------------------------------------------------
ggplot(data=Beauty) + geom_point(aes(x=age, y=beauty))


## ----cache=TRUE----------------------------------------------------------
g = ggplot(data=Beauty)
g1 = g + geom_point(aes(x=age, y=beauty))


## ----fig.keep='none'-----------------------------------------------------
g + geom_point(aes(x=age, y=beauty, colour=gender))


## ----fig.keep='none', tidy=FALSE, cache=TRUE-----------------------------
g + geom_point(aes(x=age, y=beauty, 
                   alpha=evaluation, colour=gender))


## ----fig.keep='none'-----------------------------------------------------
g + geom_point(aes(x=age, y=beauty, colour="blue"))


## ----fig.keep='none'-----------------------------------------------------
g + geom_point(aes(x=age, y=beauty), colour="blue")


## ----fig.keep='none'-----------------------------------------------------
g + geom_boxplot(aes(x=gender, y=beauty))


## ----fig.keep='none', cache=TRUE, tidy=FALSE-----------------------------
g + geom_boxplot(aes(x=gender, y=beauty, 
                             colour=factor(tenured)))


## ----eval=FALSE----------------------------------------------------------
## g + geom_boxplot(aes(x=gender, y=beauty, colour=tenured))


## ----fig.keep='none', tidy=FALSE-----------------------------------------
g + geom_boxplot(aes(x=gender, y=beauty, colour=factor(tenured)))


## ----fig.keep='none', tidy=FALSE-----------------------------------------
g + geom_boxplot(aes(x=gender, y=beauty, 
                          colour=factor(tenured))) + 
  geom_point(aes(x=gender, y=beauty)) 


## ----fig.keep='none', tidy=FALSE-----------------------------------------
g + geom_boxplot(aes(x=gender, y=beauty, 
                         colour=factor(tenured))) + 
  geom_jitter(aes(x=gender, y=beauty)) 


## ----fig.keep='none'-----------------------------------------------------
g + geom_bar(aes(x=factor(tenured)))


## ----fig.keep='none'-----------------------------------------------------
Beauty$dec = signif(Beauty$age, 1)


## ----fig.keep='none'-----------------------------------------------------
g = ggplot(data=Beauty)
g + geom_bar(aes(x=gender, fill=factor(dec)))


## ----fig.keep='none', tidy=FALSE-----------------------------------------
g + geom_bar(aes(x=gender, fill=factor(dec)), 
             position="stack")


