
## ----echo=FALSE----------------------------------------------------------
results='show';echo=TRUE


## ----setup, include=FALSE, cache=FALSE-----------------------------------
library(knitr)
options(replace.assign=FALSE,width=50)

opts_chunk$set(fig.path='knitr_figure/graphics-', 
               cache.path='knitr_cache/graphics-', 
               fig.align='center', 
               dev='pdf', fig.width=5, fig.height=5, 
               fig.show='hold', cache=FALSE, par=TRUE)
knit_hooks$set(crop=hook_pdfcrop)

knit_hooks$set(par=function(before, options, envir){
    if (before && options$fig.show!='none') {
        par(mar=c(3,3,2,1),cex.lab=.95,cex.axis=.9,
            mgp=c(2,.7,0),tcl=-.01, las=1)
}}, crop=hook_pdfcrop)


## ----message=FALSE-------------------------------------------------------
library("ggplot2") 


## ----results='hide'------------------------------------------------------
data(mpg)
dim(mpg)


## ----F1, echo=FALSE, message=FALSE, cache=TRUE, fig.keep='none',results='hide'----
data(mpg)
# mpg$drv = as.character(mpg$drv)
# mpg[mpg$drv == "f",]$drv = "Front"
# mpg[mpg$drv == "r",]$drv = "Rear"
# mpg[mpg$drv == "4",]$drv = "4wd"
# mpg$drv = factor(mpg$drv, 
#    levels = c("Front", "Rear", "4wd"))

g = ggplot(data=mpg, aes(x=displ, y=hwy)) 
g1 = g + geom_point() + stat_smooth(linetype=2) + 
  xlab("Displacement") + ylab("Highway mpg")
g2 = g1 + geom_point(data=subset(mpg, manufacturer=="audi"), 
   aes(x=displ, y=hwy), 
  colour="red", size=4, alpha=0.4)
g3 = g + geom_point() + stat_smooth(aes(colour=drv)) + 
  theme(legend.position = "top")


## ----dev='png', out.width='\\textwidth', echo=FALSE, message=FALSE-------
g1


## ----fig.keep='none', tidy=FALSE-----------------------------------------
ggplot(data=mpg, aes(x=displ, y=hwy)) +  
  geom_point() + xlab("Displacement")


## ----echo=9*echo---------------------------------------------------------
data(mpg)
# mpg$drv = as.character(mpg$drv)
# mpg[mpg$drv == "f",]$drv = "Front"
# mpg[mpg$drv == "r",]$drv = "Rear"
# mpg[mpg$drv == "4",]$drv = "4wd"
# mpg$drv = factor(mpg$drv, 
#    levels = c("Front", "Rear", "4wd"))

g = ggplot(data=mpg, aes(x=displ, y=hwy)) 
g1 = g + geom_point() + stat_smooth(linetype=2) + 
  xlab("Displacement") + ylab("Highway mpg")
g2 = g1 + geom_point(data=subset(mpg, manufacturer=="audi"), 
   aes(x=displ, y=hwy), 
  colour="red", size=4, alpha=0.4)
g3 = g + geom_point() + stat_smooth(aes(colour=drv)) + 
  theme(legend.position = "top")


## ----dev='png', out.width='\\textwidth', echo=FALSE, message=FALSE-------
g2


## ----echo=10*echo--------------------------------------------------------
data(mpg)
# mpg$drv = as.character(mpg$drv)
# mpg[mpg$drv == "f",]$drv = "Front"
# mpg[mpg$drv == "r",]$drv = "Rear"
# mpg[mpg$drv == "4",]$drv = "4wd"
# mpg$drv = factor(mpg$drv, 
#    levels = c("Front", "Rear", "4wd"))

g = ggplot(data=mpg, aes(x=displ, y=hwy)) 
g1 = g + geom_point() + stat_smooth(linetype=2) + 
  xlab("Displacement") + ylab("Highway mpg")
g2 = g1 + geom_point(data=subset(mpg, manufacturer=="audi"), 
   aes(x=displ, y=hwy), 
  colour="red", size=4, alpha=0.4)
g3 = g + geom_point() + stat_smooth(aes(colour=drv)) + 
  theme(legend.position = "top")


## ----echo=11*echo--------------------------------------------------------
data(mpg)
# mpg$drv = as.character(mpg$drv)
# mpg[mpg$drv == "f",]$drv = "Front"
# mpg[mpg$drv == "r",]$drv = "Rear"
# mpg[mpg$drv == "4",]$drv = "4wd"
# mpg$drv = factor(mpg$drv, 
#    levels = c("Front", "Rear", "4wd"))

g = ggplot(data=mpg, aes(x=displ, y=hwy)) 
g1 = g + geom_point() + stat_smooth(linetype=2) + 
  xlab("Displacement") + ylab("Highway mpg")
g2 = g1 + geom_point(data=subset(mpg, manufacturer=="audi"), 
   aes(x=displ, y=hwy), 
  colour="red", size=4, alpha=0.4)
g3 = g + geom_point() + stat_smooth(aes(colour=drv)) + 
  theme(legend.position = "top")


## ----dev='png', out.width='\\textwidth', echo=FALSE, message=FALSE-------
g3


## ----overplotting, cache=TRUE, tidy=FALSE, echo=1:7----------------------
## If your computer is slow when plotting
## reduce the value of n
n = 20000
x1 = signif(matrix(rnorm(n), ncol=2), 2)
x2 = signif(matrix(
  rnorm(n, mean=3, sd=1.5), ncol=2), 2)
x = rbind(x1, x2)
df = data.frame(x=x[,1], y=x[,2])
h= ggplot(df) + geom_point(aes(x, y))


## ----echo=FALSE----------------------------------------------------------
h


## ----echo=8--------------------------------------------------------------
## If your computer is slow when plotting
## reduce the value of n
n = 20000
x1 = signif(matrix(rnorm(n), ncol=2), 2)
x2 = signif(matrix(
  rnorm(n, mean=3, sd=1.5), ncol=2), 2)
x = rbind(x1, x2)
df = data.frame(x=x[,1], y=x[,2])
h= ggplot(df) + geom_point(aes(x, y))


## ----cache=TRUE, fig.keep='none', tidy=FALSE-----------------------------
h +  stat_density2d(aes(x,y, fill=..density..),
                contour=FALSE, geom="tile")


## ------------------------------------------------------------------------
data(diamonds)


## ----tidy=FALSE, eval=FALSE----------------------------------------------
## ?diamonds


## ----fig.keep='none', message=FALSE--------------------------------------
i1 = ggplot(data=diamonds) + 
  geom_histogram(aes(x=depth))


## ----echo=FALSE, message=FALSE-------------------------------------------
i1


## ----eval=FALSE----------------------------------------------------------
## library(nclRggplot2)
## vignette("solutions2", package="nclRggplot2")


